EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Promotions_GetScheduled',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'BuildPromotionsScheduled_Extended',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets scheduled promotions, optionally filtered by promotion and date.'
GO

IF OBJECT_ID('[Promotions_GetScheduled]') IS NOT NULL DROP PROCEDURE [Promotions_GetScheduled]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Promotions_GetScheduled]
(
	@Application_Id INT = NULL,
	@Release_Number RELEASENUMBER = NULL,
	@Build_Number BUILDNUMBER = NULL,
	@PipelineStage_Name VARCHAR(50) = NULL,
	@Before_Date DATETIME = NULL
) AS BEGIN

SET NOCOUNT ON

	IF @Application_Id IS NULL
	BEGIN

		SELECT BPS.*
		  FROM [BuildPromotionsScheduled_Extended] BPS
		       INNER JOIN [Builds] B
			           ON B.[Build_Id] = BPS.[Build_Id]
               LEFT JOIN [Releases] R
                       ON R.[Release_Id] = B.[Release_Id]
		       LEFT JOIN [BuildPromotions] BP
			          ON BP.[Build_Id] = BPS.[Build_Id]
					 AND BP.[PipelineStage_Name] = BPS.[PipelineStage_Name]
		 WHERE @Before_Date IS NULL OR BPS.[PromoteOn_Date] <= @Before_Date
		   AND BP.[Promotion_Id] IS NULL
		   AND B.[BuildStatus_Name] = 'Active'
           AND (@Application_Id IS NULL OR COALESCE(B.[Application_Id], R.[Application_Id]) = @Application_Id)
           AND (@Release_Number IS NULL OR R.[Release_Number] = @Release_Number)
           AND (@Build_Number IS NULL OR B.[Build_Number] = @Build_Number)
           AND (@PipelineStage_Name IS NULL OR BPS.[PipelineStage_Name] = @PipelineStage_Name)
		 ORDER BY BPS.[PromoteOn_Date] DESC

	END
	ELSE
	BEGIN

		SELECT BPS.*
		  FROM [BuildPromotionsScheduled_Extended] BPS
		       INNER JOIN [Builds] B
			           ON B.[Build_Id] = BPS.[Build_Id]
			   INNER JOIN [Releases] R
			           ON R.[Release_Id] = B.[Release_Id]
		       LEFT JOIN [BuildPromotions] BP
			          ON BP.[Build_Id] = BPS.[Build_Id]
					 AND BP.[PipelineStage_Name] = BPS.[PipelineStage_Name]
		 WHERE R.[Application_Id] = @Application_Id
		   AND R.[Release_Number] = COALESCE(@Release_Number, R.[Release_Number])
		   AND B.[Build_Number] = COALESCE(@Build_Number, B.[Build_Number])
		   AND BPS.[PipelineStage_Name] = COALESCE(@PipelineStage_Name, BPS.[PipelineStage_Name])
		   AND (@Before_Date IS NULL OR BPS.[PromoteOn_Date] <= @Before_Date)
		   AND BP.[Promotion_Id] IS NULL
		   AND B.[BuildStatus_Name] = 'Active'
		 ORDER BY BPS.[PromoteOn_Date] DESC

	END

END
GO

GRANT EXECUTE ON [Promotions_GetScheduled] TO [BuildMasterUser_Role]