﻿IF OBJECT_ID('[RepositoryMonitors_CreateOrUpdateRepositoryMonitor]') IS NOT NULL DROP PROCEDURE [RepositoryMonitors_CreateOrUpdateRepositoryMonitor]
GO

SET QUOTED_IDENTIFIER ON
GO

EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'RepositoryMonitors_CreateOrUpdateRepositoryMonitor',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'RepositoryMonitor_Id',
    /* Description_Text        */ 'Creates or updates a repository monitor.'
GO

CREATE PROCEDURE [RepositoryMonitors_CreateOrUpdateRepositoryMonitor]
(
	@RepositoryMonitor_Name NVARCHAR(255),
	@Application_Id INT,
	@ApplicationGroup_Id INT,
	@RepositoryMonitor_Configuration XML,
	@CronExpression_Text VARCHAR(50) = NULL,
	@Active_Indicator YNINDICATOR,
	@ExecuteOn_Server_Id INT,
	@Plan_Name VARCHAR(255),
	@BranchFilter_Text VARCHAR(255),
	@CreateVariables_Indicator YNINDICATOR = NULL,
	@ReleaseNumberFilter_Text VARCHAR(255) = NULL,
	@RepositoryMonitor_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @RepositoryMonitor_Id IS NULL

		INSERT INTO [RepositoryMonitors]
		(
			[RepositoryMonitor_Name],
			[Application_Id],
			[ApplicationGroup_Id],
			[RepositoryMonitor_Configuration],
			[CronExpression_Text],
			[Active_Indicator],
			[ExecuteOn_Server_Id],
			[Plan_Name],
			[BranchFilter_Text],
			[CreateVariables_Indicator],
			[ReleaseNumberFilter_Text]
		)
		VALUES
		(
			@RepositoryMonitor_Name,
			@Application_Id,
			@ApplicationGroup_Id,
			@RepositoryMonitor_Configuration,
			@CronExpression_Text,
			@Active_Indicator,
			@ExecuteOn_Server_Id,
			@Plan_Name,
			@BranchFilter_Text,
			COALESCE(@CreateVariables_Indicator, 'N'),
			@ReleaseNumberFilter_Text
		)

	ELSE

		UPDATE [RepositoryMonitors]
		   SET [RepositoryMonitor_Name] = @RepositoryMonitor_Name,
		       [Application_Id] = @Application_Id,
			   [ApplicationGroup_Id] = @ApplicationGroup_Id,
			   [RepositoryMonitor_Configuration] = @RepositoryMonitor_Configuration,
			   [CronExpression_Text] = @CronExpression_Text,
			   [Active_Indicator] = @Active_Indicator,
			   [ExecuteOn_Server_Id] = @ExecuteOn_Server_Id,
			   [Plan_Name] = @Plan_Name,
			   [BranchFilter_Text] = @BranchFilter_Text,
			   [CreateVariables_Indicator] = COALESCE(@CreateVariables_Indicator, [CreateVariables_Indicator]),
			   [ReleaseNumberFilter_Text] = COALESCE(@ReleaseNumberFilter_Text, [ReleaseNumberFilter_Text])
		 WHERE [RepositoryMonitor_Id] = @RepositoryMonitor_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [RepositoryMonitors_CreateOrUpdateRepositoryMonitor] TO [BuildMasterUser_Role]
