﻿IF OBJECT_ID('[Webhooks_CreateOrUpdateWebhook]') IS NOT NULL DROP PROCEDURE [Webhooks_CreateOrUpdateWebhook]
GO

SET QUOTED_IDENTIFIER ON
GO

EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Webhooks_CreateOrUpdateWebhook',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Webhook_Id',
    /* Description_Text        */ 'Creates or updates a webhook.'
GO

CREATE PROCEDURE [Webhooks_CreateOrUpdateWebhook]
(
	@Webhook_Name NVARCHAR(255),
	@Application_Id INT,
	@Webhook_Configuration XML,
	@Active_Indicator YNINDICATOR,
	@Plan_Name VARCHAR(255),
	@CreateVariables_Indicator YNINDICATOR = NULL,
	@Webhook_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @Webhook_Id IS NULL

		INSERT INTO [Webhooks]
		(
			[Webhook_Name],
			[Application_Id],
			[Webhook_Configuration],
			[Active_Indicator],
			[Plan_Name],
			[CreateVariables_Indicator]
		)
		VALUES
		(
			@Webhook_Name,
			@Application_Id,
			@Webhook_Configuration,
			@Active_Indicator,
			@Plan_Name,
			COALESCE(@CreateVariables_Indicator, 'N')
		)

	ELSE

		UPDATE [Webhooks]
		   SET [Webhook_Name] = @Webhook_Name,
		       [Application_Id] = @Application_Id,
			   [Webhook_Configuration] = @Webhook_Configuration,
			   [Active_Indicator] = @Active_Indicator,
			   [Plan_Name] = @Plan_Name,
			   [CreateVariables_Indicator] = COALESCE(@CreateVariables_Indicator, [CreateVariables_Indicator])
		 WHERE [Webhook_Id] = @Webhook_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Webhooks_CreateOrUpdateWebhook] TO [BuildMasterUser_Role]
